# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.orders_api import OrdersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestOrdersApi(unittest.TestCase):
    """OrdersApi unit test stubs"""

    def setUp(self):
        self.api = OrdersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_options(self):
        """Test case for cancel_options

        This method is used to select cancel reasons according to delivery option.  # noqa: E501
        """
        pass

    def test_cancel_order(self):
        """Test case for cancel_order

        This method is used to cancel  the order.  # noqa: E501
        """
        pass

    def test_cancelled_orders(self):
        """Test case for cancelled_orders

        It is used to get the list of cancelled orders by shop.  # noqa: E501
        """
        pass

    def test_chain_unapproved_orders(self):
        """Test case for chain_unapproved_orders

        It is used to get the list of unapproved orders by chain.  # noqa: E501
        """
        pass

    def test_deliver_order(self):
        """Test case for deliver_order

        This method is used for the delivery of the prepared order.  # noqa: E501
        """
        pass

    def test_get_active_orders(self):
        """Test case for get_active_orders

        It is used to get the list of active orders by shop.  # noqa: E501
        """
        pass

    def test_get_order(self):
        """Test case for get_order

        This method is used to get details of an order  # noqa: E501
        """
        pass

    def test_get_order_report(self):
        """Test case for get_order_report

        It is used to get the list of orders by shopIds,startDate and endDate.  # noqa: E501
        """
        pass

    def test_get_shop_delivered_orders(self):
        """Test case for get_shop_delivered_orders

        It is used to get the list of delivered orders by shopId,startDate and endDate.  # noqa: E501
        """
        pass

    def test_handover_order(self):
        """Test case for handover_order

        This method is used for the delivery of the prepared order to the courier.  # noqa: E501
        """
        pass

    def test_prepare_order(self):
        """Test case for prepare_order

        This method is used to change the prepared order to the prepared status  # noqa: E501
        """
        pass

    def test_send_invoice(self):
        """Test case for send_invoice

        This method is used to send the order's invoice to the client  # noqa: E501
        """
        pass

    def test_unapproved_orders(self):
        """Test case for unapproved_orders

        It is used to get the list of unapproved orders by shop.  # noqa: E501
        """
        pass

    def test_verify_order(self):
        """Test case for verify_order

        This method is used to approve the incoming order by the shop  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
