from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from swagger_client.api.auth_api import AuthApi
from swagger_client.api.health_api import HealthApi
from swagger_client.api.orders_api import OrdersApi
from swagger_client.api.products_api import ProductsApi
from swagger_client.api.shops_api import ShopsApi
from swagger_client.api.supplier_api import SupplierApi
